////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	22/10/2021
//!
//! \par	Function:
//!	Contains the declaration of the GraphicSpace::EnumeratedException class.
//!
////////////////////////////////////////////////////////////////////////////////

# if	!defined ENUMERATED_EXCEPTION_H

# define	ENUMERATED_EXCEPTION_H

# include	"Exception.h"

namespace	GraphicSpace
{

////////////////////////////////////////////////////////////////////////////////
//! \enum	EnumeratedExceptionType
//!	The EnumeratedExceptionType type represents the exceptions thrown when
//!	an enumerated command line parameter is not correct.
//!
//! \note
//!	The sequence of values must correspond to the Message array in the
//!	EnumeratedException class.
//!
//! \see	EnumeratedException
//!
////////////////////////////////////////////////////////////////////////////////

enum	class	EnumeratedExceptionType
	{

		//! Invalid Randomize parameter.
	INVALID_RANDOMIZE_PARAMETER,

		//! Invalid Pathchoice parameter.
	INVALID_PATH_CHOICE_PARAMETER,

		//! Invalid TruncatePath parameter.
	INVALID_TRUNCATE_PATH_PARAMETER,

		//! Invalid Quiet parameter.
	INVALID_QUIET_PARAMETER

	};

////////////////////////////////////////////////////////////////////////////////
//! \class	EnumeratedException
//!	The EnumeratedExceptionType type represents the exceptions thrown when
//!	an enumerated command line parameter is not correct.
//!
////////////////////////////////////////////////////////////////////////////////

class	EnumeratedException: private Exception
	{
	private:

//! \property	ExceptionKind
//!	Kind of the exception.
			EnumeratedExceptionType	ExceptionKind;

//! \property	ErrorFormat
//!	Format string used to write error messages with a number.
		static	const	char*	const	ErrorFormat;

//! \property	Message
//!	Array of error messages, one for each error.
//!
//! \note
//!	The sequence of messages must correspond to the sequence of values of
//!	the EnumeratedExceptionType type.
//!
//! \see EnumeratedExceptionType 
		static	const	char*	const	Message [];

	public:

			EnumeratedException(EnumeratedExceptionType
				thisExceptionKind) noexcept;

			~EnumeratedException(void) noexcept = default;

		void	Write(FILE* OutputFile) const noexcept override;

	};

}

# endif
