////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	20/09/2021
//!
//! \par	Function:
//!	Contains the declaration of the GraphicSpace::FileException class.
//!
////////////////////////////////////////////////////////////////////////////////

# if	!defined FILE_EXCEPTION_H

# define	FILE_EXCEPTION_H

# include	"Exception.h"

namespace	GraphicSpace
{

////////////////////////////////////////////////////////////////////////////////
//! \enum	FileExceptionType
//!	The FileExceptionType type represents the file exceptions.
//!
//! \note
//!	The sequence of values must correspond to the Message array in the
//!	FileException class.
//!
//! \see	FileException
//!
////////////////////////////////////////////////////////////////////////////////

enum	class	FileExceptionType
	{
		// Error while opening a file.
	FILE_OPEN_ERROR,

		// Error while reading a file.
	FILE_READ_ERROR,

		// Error while writing a file.
	FILE_WRITE_ERROR,

		// Error while seeking on a file.
	FILE_SEEK_ERROR,

		// Error while closing a file.
	FILE_CLOSE_ERROR

	};

////////////////////////////////////////////////////////////////////////////////
//! \class	FileException
//!	The FileException class represents a graphic exceptions throw during an
//!	I/O operation.
//!
////////////////////////////////////////////////////////////////////////////////

class	FileException: private Exception
	{
	private:

//! \property	ExceptionKind
//!	Kind of the exception.
			FileExceptionType	ExceptionKind;

//! \property	FileName
//!	Name of the file that caused the exception;
			const	char*		FileName;

//! \property	ErrorFormat
//!	Format string used to write error messages.
		static	const	char*	const	ErrorFormat;

//! \property	Message
//!	Array of error messages, one for each error.
//!
//! \note
//!	The sequence of messages must correspond to the sequence of values of
//!	the FileExceptionType type.
//!
//! \see FileExceptionType 
		static	const	char*	const	Message [];

	public:

				FileException(FileExceptionType
					thisExceptionKind,
					const char* thisFilename) noexcept;

				FileException(const FileException& Argument)
					noexcept = default;

				FileException(FileException&& Argument)
					noexcept = default;

				~FileException(void) noexcept = default;

		FileException&	operator = (const FileException&
						Argument) noexcept = default;

		FileException&	operator = (FileException&& Argument)
						noexcept = default;

		void		Write(FILE* OutputFile) const noexcept override;

	};

}

# endif
