////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	06/10/2021
//!
//! \par	Function:
//!	Contains the declaration of the GraphicSpace::FloatException class.
//!
////////////////////////////////////////////////////////////////////////////////

# if	!defined FLOAT_EXCEPTION_H

# define	FLOAT_EXCEPTION_H

# include	"Exception.h"

namespace	GraphicSpace
{

////////////////////////////////////////////////////////////////////////////////
//! \enum	FloatExceptionType
//!	The FloatExceptionType type represents the exceptions thrown when an
//!	input floating point parameter value is outside the valid range.
//!
//! \note
//!	The sequence of values must correspond to the Message array in the
//!	FloatException class.
//!
//! \see	FloatException
//!
////////////////////////////////////////////////////////////////////////////////

enum	class	FloatExceptionType
	{

		//! Invalid repulsion step parameter.
	INVALID_REPULSION_STEP,

		//! Invalid exponent of the repulsion parameter.
	INVALID_ALPHA,

		//! Invalid exponent of the attraction parameter.
	INVALID_BETA

	};

////////////////////////////////////////////////////////////////////////////////
//! \class	FloatException
//!	The FloatException class represents an exceptions thrown because a
//!	floating point number is outside its valid range.
//!
////////////////////////////////////////////////////////////////////////////////

class	FloatException: private Exception
	{
	private:

//! \property	ExceptionKind
//!	Kind of the exception.
			FloatExceptionType	ExceptionKind;

//! \property	Value
//!	Value that caused the exception.
			float			Value;

//! \property	ErrorFormat
//!	Format string used to write error messages with a number.
		static	const	char*	const	ErrorFormat;

//! \property	Message
//!	Array of error messages, one for each error.
//!
//! \note
//!	The sequence of messages must correspond to the sequence of values of
//!	the FloatExceptionType type.
//!
//! \see FloatExceptionType 
		static	const	char*	const	Message [];

	public:

			FloatException(FloatExceptionType thisExceptionKind,
				float thisValue) noexcept;

			~FloatException(void) noexcept = default;

		void	Write(FILE* OutputFile) const noexcept override;

	};

}

# endif
