////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	22/09/2021
//!
//! \par	Function:
//!	General purpose include file for all the graphic environment files.
//!
////////////////////////////////////////////////////////////////////////////////

# if	!defined GRAPHIC_H

# include	<assert.h>
# include	<limits.h>
# include	<inttypes.h>

//! \def	PURE_VIRTUAL
//!	Constant used to define C++ pure virtual functions, to make their
//!	declaration more readable.
# define	PURE_VIRTUAL		= 0

//! \var	END_STRING
//!	String terminator character.
static	constexpr	char	END_STRING = '\0';

//! \var	DECIMAL_BASE
//!	Base used in number conversions. All digits in the decimal system have a
//!	value smaller than this.
static	constexpr	int	DECIMAL_BASE = 10;

//! \var	STANDARD_OUTPUT
//!	Path of the standard output file.
static	constexpr	const	char*	STANDARD_OUTPUT = "<standard output>";

////////////////////////////////////////////////////////////////////////////////
//!
//! \defgroup	CommonMacros	Common Macros
//!	Definitions of commonly used macros.
//!
//!	\{
//!
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//! \def	IgnoreValue(expression)
//!	Ignore the value of an expression, casting it to void. \n
//!	Mostly useful for function calls.
//!
//! \param	Expression	The expression
//!
////////////////////////////////////////////////////////////////////////////////

# define	IgnoreValue(Expression)	(static_cast<void>(Expression))

////////////////////////////////////////////////////////////////////////////////
//! \def	NumberOfElements(array)
//!	Computes the number of elements in a statically allocated array.
//!
//! \param	Array	The array name
//!
////////////////////////////////////////////////////////////////////////////////

# define	NumberOfElements(Array)	(sizeof(Array) / sizeof((Array) [0]))

////////////////////////////////////////////////////////////////////////////////
//!	\}
////////////////////////////////////////////////////////////////////////////////

# endif
