////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	19/11/2021
//!
//! \par	Function:
//!	Contains the declaration of the GraphicSpace::Interpolator class.
//!
////////////////////////////////////////////////////////////////////////////////

# if	!defined INTERPOLATOR_H

# define	INTERPOLATOR_H

namespace	GraphicSpace
{

////////////////////////////////////////////////////////////////////////////////
//! \class	Interpolator
//!	The Interpolator class represents a bidimensional linear
//!	interpolator. \n
//!	In can linearly interpolate values inside a square, given the values at
//!	the corners.
//!
////////////////////////////////////////////////////////////////////////////////

class	Interpolator
	{
	private:

//! \var	MAXIMUM_INTERPOLATION_SIZE
//!	Maximum side of the quare in which the interpolation is performed.
static	constexpr	unsigned int	MAXIMUM_INTERPOLATION_SIZE = 5;

////////////////////////////////////////////////////////////////////////////////
//! \class	Coefficient
//!	The Coefficient struct contains the coeffients used to interpolate a
//!	value inside a square.
//!
////////////////////////////////////////////////////////////////////////////////

		struct	Coefficient
			{

//! \property	UpperLeft
//!	Coefficient of the upper left value.
			unsigned int	UpperLeft;

//! \property	UpperRight
//!	Coefficient of the upper right value.
			unsigned int	UpperRight;

//! \property	LowerLeft
//!	Coefficient of the lower left value.
			unsigned int	LowerLeft;

//! \property	LowerRight
//!	Coefficient of the lower right value.
			unsigned int	LowerRight;

			};

//! \property	Size
//!	Number of elements in a side of the square.
		unsigned int	Size;

//! \property	SquaredSize
//!	Square of the number of elements in a side of the square.
		unsigned int	SquaredSize;

//! \property	InterpolationTable
//!	Array of the coeffients, one for each point in the square.
//!
//! \see	MAXIMUM_INTERPOLATION_SIZE
		Coefficient	InterpolationTable [MAXIMUM_INTERPOLATION_SIZE]
						[MAXIMUM_INTERPOLATION_SIZE];

	public:

				Interpolator(register unsigned int thisSize)
					noexcept(false);

		uint_least32_t	operator () (unsigned int Row,
					unsigned int Column,
					uint_least32_t UpperLeft,
					uint_least32_t UpperRight,
					uint_least32_t LowerLeft,
					uint_least32_t LowerRight) const
					noexcept;

	};

}

# include	"Interpolator.inl"

# endif
