////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	08/04/2023
//!
//! \par	Function:
//!	Contains the declaration of the GraphicSpace::Mutex class.
//!
////////////////////////////////////////////////////////////////////////////////

# if	!defined MUTEX_H

# define	MUTEX_H

# include	<pthread.h>

namespace	GraphicSpace
{

////////////////////////////////////////////////////////////////////////////////
//! \class	Mutex
//!	The Mutex class represents a mutex region.
//!
////////////////////////////////////////////////////////////////////////////////

class	Mutex
	{
	private:

//! \property	MUTEX_INIT_OK
//!	Value returned by pthread_mutex_init when the operation succeeds.
		static	constexpr	unsigned int	MUTEX_INIT_OK = 0;

//! \property	MUTEX_DESTROY_OK
//!	Value returned by pthread_mutex_destroy when the operation succeeds.
		static	constexpr	unsigned int	MUTEX_DESTROY_OK = 0;

//! \property	MUTEX_LOCK_OK
//!	Value returned by pthread_mutex_lock when the operation succeeds.
		static	constexpr	unsigned int	MUTEX_LOCK_OK = 0;

//! \property	MUTEX_UNLOCK_OK
//!	Value returned by pthread_mutex_unlock when the operation succeeds.
		static	constexpr	unsigned int	MUTEX_UNLOCK_OK = 0;

//! \property	Active
//!	Flag indicating whether the Mutex is initialized.
			bool		Active;

//! \property	MutexData
//!	Mutex data.
			pthread_mutex_t	MutexData;

	public:

					Mutex(void) noexcept;

					Mutex(const Mutex& thisThread) = delete;

					Mutex(Mutex&& thisMutex) = delete;

					~Mutex(void) noexcept(false);

			Mutex&		operator = (const Mutex& thisMutex) =
						delete;

			Mutex&		operator = (Mutex&& thisMutex) = delete;

			void		Initialize(void) noexcept(false);

			void		Finalize(void) noexcept(false);

			void		Lock(void) noexcept(false);

			void		Unlock(void) noexcept(false);

	};

}

# endif
