////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	05/10/2021
//!
//! \par	Function:
//!	Contains the declaration of the GraphicSpace::NameException class.
//!
////////////////////////////////////////////////////////////////////////////////

# if	!defined Name_EXCEPTION_H

# define	Name_EXCEPTION_H

# include	"Exception.h"
# include	"Bitmap.h"

namespace	GraphicSpace
{

////////////////////////////////////////////////////////////////////////////////
//! \enum	NameExceptionType
//!	The NameExceptionType type represents the file exceptions.
//!
//! \note
//!	The sequence of values must correspond to the Message array in the
//!	NameException class.
//!
//! \see	NameException
//!
////////////////////////////////////////////////////////////////////////////////

enum	class	NameExceptionType
	{

		//! Invalid file type name.
	INVALID_TYPE_NAME

	};

////////////////////////////////////////////////////////////////////////////////
//! \class	ValueException
//!	The ValueException class represents a graphic exceptions throw while
//!	reading a bitmap file.
//!
////////////////////////////////////////////////////////////////////////////////

class	NameException: private Exception
	{
	private:

//! \property	ExceptionKind
//!	Kind of the exception.
			NameExceptionType	ExceptionKind;

//! \property	String
//!	String that caused the exception.
			char			String [Bitmap::
							HEADER_NAME_LENGTH];

//! \property	ErrorFormat
//!	Format string used to write error messages.
		static	const	char*	const	ErrorFormat;

//! \property	Message
//!	Array of error messages, one for each error.
//!
//! \note
//!	The sequence of messages must correspond to the sequence of values of
//!	the NameExceptionType type.
//!
//! \see NameExceptionType 
		static	const	char*	const	Message [];

	public:

			NameException(const uint8_t Name
				[Bitmap::HEADER_NAME_LENGTH]) noexcept;

			~NameException(void) noexcept = default;

		void	Write(FILE* OutputFile) const noexcept override;

	};

}

# endif
