////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	16/10/2021
//!
//! \par	Function:
//!	Contains the declaration of the GraphicSpace::ParameterDescriptor class.
//!
////////////////////////////////////////////////////////////////////////////////

# if	!defined PARAMETER_DESCRIPTOR_H

# define	PARAMETER_DESCRIPTOR_H

# include	"Bitmap.h"

# include	<string.h>

namespace	GraphicSpace
{

////////////////////////////////////////////////////////////////////////////////
//! \class	ParameterDescriptor
//!	The ParameterDescriptor abstract class represents the descriptor of a
//!	command line option.
//!
////////////////////////////////////////////////////////////////////////////////

class	ParameterDescriptor
	{

	private:

//! \property	Name
//!	String used to identify the parameter.
			const	char*	Name;

				ParameterDescriptor(const ParameterDescriptor&
					Descriptor) noexcept = delete;

				ParameterDescriptor(ParameterDescriptor&&
					Descriptor) noexcept = delete;

			void	operator = (const ParameterDescriptor&
					Descriptor) noexcept = delete;

			void	operator = (ParameterDescriptor&& Descriptor)
					noexcept = delete;

	protected:

				ParameterDescriptor(const char* thisName)
					noexcept;

		virtual		~ParameterDescriptor(void) noexcept;

	public:

//! \property	EQUAL_CHARACTER 
//!	Character representing the equal sign.
		static	constexpr	char	EQUAL_CHARACTER = '=';

			const	char*	GetName(void) const noexcept;

		virtual		void	Assign(const char* String,
						Bitmap::CorrectionParameters&
						Parameters) const
						noexcept(false) PURE_VIRTUAL;

		virtual		void	PrintUsage(const
						Bitmap::CorrectionParameters&
						DefaultParameters) const
						noexcept(false) PURE_VIRTUAL;

	};

}

# include	"ParameterDescriptor.inl"

# endif
