////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	16/10/2021
//!
//! \par	Function:
//!	It contains the definitions of inline functions of the
//!	GraphicSpace::ParameterDescriptor abstract class.
//!
////////////////////////////////////////////////////////////////////////////////

namespace	GraphicSpace
{

////////////////////////////////////////////////////////////////////////////////
//! \par	Description:
//!	Constructor.
//!
//! \param	thisName	Pointer to the string containing the name of the
//!				parameter.
//!
//! \throw	None.
//!
//! \returns	Not applicable.
//!
//! \note
//!	if thisName is not a valid pointer to a properly terminated string, the
//!	behavior is undefined.
//!
////////////////////////////////////////////////////////////////////////////////

inline	ParameterDescriptor::ParameterDescriptor(const char* thisName) noexcept:
		Name(strcpy(new char [strlen(thisName) + 1], thisName))
	{
	}

////////////////////////////////////////////////////////////////////////////////
//! \par	Description:
//!	Destructor.
//!
//! \throw	None.
//!
//! \returns	Not applicable.
//!
////////////////////////////////////////////////////////////////////////////////

inline	ParameterDescriptor::~ParameterDescriptor(void) noexcept
	{
	delete [] Name;
	}

////////////////////////////////////////////////////////////////////////////////
//! \par	Description:
//!	Get the name of the parameter.
//!
//! \throw	None.
//!
//! \returns	const	char*	Pointer to the name of the parameter.
//!
////////////////////////////////////////////////////////////////////////////////

inline	const	char*	ParameterDescriptor::GetName(void) const noexcept
	{
	return Name;
	}

}
