////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	27/09/2021
//!
//! \par	Function:
//!	It contains the declaration of the GraphicSpace::RandomGenerator class.
//!
////////////////////////////////////////////////////////////////////////////////

# if !defined	RANDOM_GENERATOR_H

# define	RANDOM_GENERATOR_H

# include	"SimpleRandomGenerator.h"

namespace	GraphicSpace
{

////////////////////////////////////////////////////////////////////////////////
//! \class	RandomGenerator
//!	The RandomGenerator class represents a random numbers generator, based
//!	upon an array of linear congruent random numbers generator. \n
//!	Proper choice of the parameter ensures that the cycle of generated
//!	numbers does not repeats itself with Universe existence.
//!
////////////////////////////////////////////////////////////////////////////////

class	RandomGenerator
	{
	public:

//! \property	NUMBER_OF_GENERATORS
//!	Number of linear congruent generators used.
		static	constexpr	unsigned int	NUMBER_OF_GENERATORS =
								29;

//! \property	MINIMUM_MODULE
//!	Minimum module of the generators.
		static	constexpr	unsigned int	MINIMUM_MODULE =
								4273367641;

	private:

//! \property	Selector
//!	Random number generator, used to select one of the generators in the
//!	Generator array.
		SimpleRandomGenerator	Selector;

//! \property	Generator
//!	Random number generator, used to select one of the generators in the
//!	Generator array.
		SimpleRandomGenerator	Generator [NUMBER_OF_GENERATORS];

	public:

					RandomGenerator(void) noexcept;

					RandomGenerator(const RandomGenerator&
						Argument) noexcept = default;

					RandomGenerator(RandomGenerator&&
						Argument) noexcept = default;

		RandomGenerator&	operator = (const RandomGenerator&
						Argument) noexcept = default;

		RandomGenerator&	operator = (RandomGenerator&& Argument)
						noexcept = default;

					~RandomGenerator(void) noexcept =
						default;

		void			SetSeed(const uint_fast32_t Seed
						[NUMBER_OF_GENERATORS + 1])
						noexcept;

		void			GetSeed(uint_fast32_t Seed
						[NUMBER_OF_GENERATORS + 1])
						const noexcept;

		void			ModifySeed(uint_fast32_t Value)
						noexcept;

		uint_fast32_t		Generate(uint_fast32_t Maximum)
						noexcept;

		unsigned int		Select(register const uint_fast32_t*
						Probability,
						unsigned int Elements) noexcept;

	};

}

# include	"RandomGenerator.inl"

# endif
