////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	16/08/2022
//!
//! \par	Function:
//!	Contains the declaration of the GraphicSpace::Thread class.
//!
////////////////////////////////////////////////////////////////////////////////

# if	!defined THREAD_H

# define	THREAD_H

# include	<pthread.h>

namespace	GraphicSpace
{

////////////////////////////////////////////////////////////////////////////////
//! \class	Thread
//!	The Thread class represents a thread.
//!
////////////////////////////////////////////////////////////////////////////////

class	Thread
	{
	private:

//! \property	ATTRIBUTE_INIT_OK
//!	Value returned by pthread_attr_init when the operation succeeds.
		static	constexpr	unsigned int	ATTRIBUTE_INIT_OK = 0;

//! \property	ATTRIBUTE_SET_OK
//!	Value returned by pthread_attr_setsched_policy,
//!	pthread_attr_setschedparam, pthread_attr_setdetachstate and
//!	pthread_attr_setinheritsched when the operation succeeds.
		static	constexpr	unsigned int	ATTRIBUTE_SET_OK = 0;

//! \property	PARAMETER_GET_OK
//!	Value returned by sched_getparam when the operation succeeds.
		static	constexpr	unsigned int	PARAMETER_GET_OK = 0;

//! \property	THREAD_CREATE_OK
//!	Value returned by pthread_create when the operation succeeds.
		static	constexpr	unsigned int	THREAD_CREATE_OK = 0;

//! \property	THREAD_JOIN_OK
//!	Value returned by pthread_join when the operation succeeds.
		static	constexpr	unsigned int	THREAD_JOIN_OK = 0;

//! \property	ThreadId
//!	Thread identifier.
			pthread_t	ThreadId;

//! \property	ThreadAttribute
//!	Thread attributes.
		static	pthread_attr_t	ThreadAttribute;

//! \property	MainThreadId
//!	Identifier of the initial thread.
		static	pthread_t	MainThreadId;

	public:

//! \typedef	ThreadFunctionType
//!	Type of the thread function.
		typedef	void		*(*ThreadFunctionType)(void* Argument);

					Thread(void) noexcept;

					Thread(const Thread& thisThread) =
						delete;

					Thread(Thread&& thisThread) = delete;

					~Thread(void) noexcept;

			Thread&		operator = (const Thread& thisThread) =
						delete;

			Thread&		operator = (Thread&& thisThread) =
						delete;

			void		Start(ThreadFunctionType
						ThreadFunction,
						void* Argument) noexcept(false);

			void		Kill(void) noexcept(false);

			void		Join(void) noexcept(false);

		static	void		Initialize(void) noexcept(false);

		static	void		Finalize(void) noexcept;

	};

}

# endif
