#===============================================================================
# Compiler flags for Linux
#===============================================================================

#===============================================================================
# General flags
#===============================================================================

CC_GENERAL_FLAGS		=			\
	-c						\
	-pipe


#===============================================================================
# C++ language definition flags
#===============================================================================

CC_LANGUAGE_DEFINITION		=			\
	-fno-nonansi-builtins				\
	-pedantic-errors				\
	-std=c++11					\
	-fno-gnu-keywords				\
	-ftemplate-depth-100				\
	-fconstexpr-depth=512				\
	-fno-implement-inlines				\
	-fstrict-enums					\
	-fvtable-verify=none


#===============================================================================
# Debug flags
#===============================================================================

CC_DEBUG_FLAGS	=					\
	-g						\
	-Og						\
	-fsanitize=undefined


#===============================================================================
# Optimization flags
#===============================================================================

CC_OPTIMIZATION_FLAGS		=			\
	-O3						\
	-fomit-frame-pointer				\
	-foptimize-sibling-calls			\
	-finline-functions				\
	-finline-functions-called-once			\
	-finline-limit=10000				\
	-fno-keep-static-consts				\
	-fmodulo-sched					\
	-fmodulo-sched-allow-regmoves			\
	-fsplit-wide-types				\
	-fgcse-sm					\
	-fgcse-las					\
	-fgcse-after-reload				\
	-fdevirtualize-speculatively			\
	-fdevirtualize-at-ltrans			\
	-flive-range-shrinkage				\
	-fira-region=all				\
	-fsched-stalled-insns=20			\
	-fsched-stalled-insns-dep=10			\
	-fsched-pressure				\
	-fipa-pta					\
	-ftree-loop-linear				\
	-floop-interchange				\
	-floop-strip-mine				\
	-floop-block					\
	-floop-unroll-and-jam				\
	-floop-parallelize-all				\
	-fgraphite-identity				\
	-ftree-loop-distribution			\
	-ftree-loop-im					\
	-ftree-loop-ivcanon				\
	-fivopts					\
	-ftree-vectorize				\
	-ftracer					\
	-fvariable-expansion-in-unroller		\
	-funroll-loops					\
	-fpeel-loops					\
	-fmove-loop-invariants				\
	-funswitch-loops				\
	-fbranch-target-load-optimize			\
	-fbranch-target-load-optimize2			\
	-fstdarg-opt					\
	--param max-crossjump-edges=100			\
	--param min-crossjump-insns=10			\
	--param max-grow-copy-bb-insns=20		\
	--param max-goto-duplication-insns=20		\
	--param max-delay-slot-insn-search=20		\
	--param max-delay-slot-live-search=20		\
	--param max-inline-insns-single=1000		\
	--param max-inline-insns-auto=200		\
	--param large-function-insns=5000		\
	--param large-function-growth=500		\
	--param large-unit-insns=50000			\
	--param inline-unit-growth=200			\
#	--param ipcp-unit-growth=200			\
	--param large-stack-frame=1000			\
	--param large-stack-frame-growth=20000		\
	--param max-inline-insns-recursive=1000		\
	--param max-inline-insns-recursive-auto=1000	\
	--param max-inline-recursive-depth=1000		\
	--param max-inline-recursive-depth-auto=1000	\
	--param early-inlining-insns=1000		\
	--param gcse-cost-distance-ratio=20		\
	--param gcse-unrestricted-cost=0		\
	--param max-unrolled-insns=40			\
	--param max-average-unrolled-insns=50		\
	--param max-unroll-times=12			\
	--param max-peeled-insns=20			\
	--param max-peel-times=5			\
	--param max-completely-peeled-insns=100		\
	--param max-completely-peel-times=10		\
	--param max-unswitch-insns=50			\
	--param max-unswitch-level=10			\
	--param lim-expensive=5				\
	--param scev-max-expr-size=100			\
	--param max-cse-path-length=50			\
	--param max-cse-insns=5000			\
	--param max-reload-search-insns=500		\
	--param max-cselib-memory-locations=2000	\
	--param max-sched-ready-insns=500		\
	--param max-sched-region-blocks=20		\
	--param max-pipeline-region-blocks=30		\
	--param max-sched-region-insns=200		\
	--param max-pipeline-region-insns=500		\
	--param max-sched-extend-regions-iters=5	\
	--param max-sched-insn-conflict-delay=5		\
	--param max-last-value-rtl=20000		\
	--param integer-share-limit=65536		\
	--param l1-cache-line-size=64			\
	--param l1-cache-size=16


#===============================================================================
# CPU specific optimization flags
#===============================================================================

CC_MACHINE_OPTIMIZATION_FLAGS	=			\
	-minline-all-stringops				\

#===============================================================================
# Warning flags
#===============================================================================

CC_WARNING_FLAGS		=			\
	-Wtrigraphs					\
	-Wchar-subscripts				\
	-Wcomment					\
	-Wformat					\
	-Wformat-security				\
	-Wformat-signedness				\
	-Wformat-y2k					\
	-Winit-self					\
	-Wignored-qualifiers				\
	-Wmain						\
	-Wmissing-braces				\
	-Wmissing-include-dirs				\
	-Wsequence-point				\
	-Wreturn-type					\
	-Wswitch					\
	-Wswitch-bool					\
	-Wtrigraphs					\
	-Wunused-but-set-parameter			\
	-Wunused-but-set-variable			\
	-Wunused-function				\
	-Wunused-label					\
	-Wunused-local-typedefs				\
	-Wunused-parameter				\
	-Wunused-variable				\
	-Wunused-value					\
	-Wuninitialized					\
	-Wunknown-pragmas				\
	-Wsuggest-attribute=pure			\
	-Wsuggest-attribute=const			\
	-Wsuggest-attribute=noreturn			\
	-Wsuggest-attribute=format			\
	-Wsuggest-final-types				\
	-Wsuggest-final-methods				\
	-Wsuggest-override				\
	-Warray-bounds=1				\
	-Wbool-compare					\
	-Wextra						\
	-Wfloat-equal					\
	-Wundef						\
	-Wshadow					\
	-Wpointer-arith					\
	-Wcast-qual					\
	-Wcast-align					\
	-Wwrite-strings					\
	-Wconversion					\
	-Wenum-compare					\
	-Wsign-compare					\
	-Wsign-conversion				\
	-Wfloat-conversion				\
	-Wsizeof-pointer-memaccess			\
	-Wsizeof-array-argument				\
	-Wmemset-transposed-args			\
	-Waddress					\
	-Wlogical-op					\
	-Wno-aggressive-loop-optimizations		\
	-Wmissing-declarations				\
	-Wmissing-field-initializers			\
	-Wredundant-decls				\
	-Winvalid-pch					\
	-Wvolatile-register-var				\
	-Woverlength-strings				\
	-Wunused-macros					\
	-Wendif-labels					\
	-Wctor-dtor-privacy				\
	-Wdelete-non-virtual-dtor			\
	-Wnarrowing					\
	-Wnoexcept					\
	-Wnon-virtual-dtor				\
	-Wreorder					\
	-Weffc++					\
	-Wstrict-null-sentinel				\
	-Wold-style-cast				\
	-Woverloaded-virtual				\
	-Wsign-promo					\
	-Wzero-as-null-pointer-constant


#===============================================================================
# Complete set of flags for the compiler
#===============================================================================

CC_LINUX_FLAGS			=			\
		$(CC_GENERAL_FLAGS)			\
		$(CC_LANGUAGE_DEFINITION)		\
		$(CC_OPTIMIZATION_FLAGS)		\
		$(CC_MACHINE_OPTIMIZATION_FLAGS)	\
		$(CC_WARNING_FLAGS)

