////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	26/10/2021
//!
//! \par	Function:
//!	This file contains the definition of the specialization of the non
//!	inline functions of the GraphicSpace::EnumeratedParameterDescriptor
//!	class template, with ENUMERATED_TYPE equal to ChoiceType.
//!
////////////////////////////////////////////////////////////////////////////////

# include	"Graphic.h"
# include	"EnumeratedParameterDescriptor.h"

namespace	GraphicSpace
{

//!	Template specialization valid when ENUMERATED_TYPE is ChoiceType.
template<>
const	char*	const
	EnumeratedParameterDescriptor<Bitmap::ChoiceType>::ValueString [] =
	{ "Random", "Maximum" };

////////////////////////////////////////////////////////////////////////////////
//! \par	Description:
//!	Return the number of strings describing the enumerated parameter. \n
//!	Template specialization valid when ENUMERATED_TYPE is ChoiceType.
//!
//! \throw	None.
//!
//! \returns	unsigned int	The number of strings describing the enumerated
//!				parameter.
//!
////////////////////////////////////////////////////////////////////////////////

template<>
unsigned int	EnumeratedParameterDescriptor<Bitmap::ChoiceType>::
			GetNumberOfValues(void) const noexcept
	{
	return NumberOfElements(ValueString);
	}

}
