////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	22/10/2021
//!
//! \par	Function:
//!	Contains the definitions of non inline functions of the
//!	GraphicSpace::EnumeratedException class.
//!
////////////////////////////////////////////////////////////////////////////////

# include	"Graphic.h"
# include	"EnumeratedException.h"

# include	<string.h>

namespace	GraphicSpace
{

const	char*	const	EnumeratedException::ErrorFormat =
	"Input data error: %s\n";

const	char*	const	EnumeratedException::Message [] =
	{
	"invalid Randomize",
	"invalid PathChoice",
	"invalid TruncatePath",
	"invalid Quiet"
	};

////////////////////////////////////////////////////////////////////////////////
//! \par	Description:
//!	Constructor.
//!
//! \param	thisExceptionKind	Kind of the exception.
//!
//! \throw	None.
//!
//! \returns	Not applicable
//!
////////////////////////////////////////////////////////////////////////////////

EnumeratedException::EnumeratedException(EnumeratedExceptionType
	thisExceptionKind) noexcept: Exception(),
	ExceptionKind(thisExceptionKind)
	{
	}

////////////////////////////////////////////////////////////////////////////////
//! \par	Description:
//!	Write an error message.
//!
//! \param	OutputFile	Pointer to the file on which the message will be
//!				written.
//!
//! \throw	None.
//!
//! \returns	None.
//!
//! \note
//!	If OutputFile is not a valid file, opened for writing, the behavior is
//!	unpredictable.
//!
//! \note
//!	If an error occurs while writing on OutputFile, the process is
//!	terminated.
//!
////////////////////////////////////////////////////////////////////////////////

void	EnumeratedException::Write(FILE* OutputFile) const noexcept
	{
	if (fprintf(OutputFile, ErrorFormat,
		Message [static_cast<unsigned int>(ExceptionKind)]) < 0)
		FatalError();
	}

}
