////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	06/10/2021
//!
//! \par	Function:
//!	Contains the definitions of non inline functions of the
//!	GraphicSpace::FloatException class.
//!
////////////////////////////////////////////////////////////////////////////////

# include	"Graphic.h"
# include	"FloatException.h"

# include	<string.h>

namespace	GraphicSpace
{

const	char*	const	FloatException::ErrorFormat =
	"Parameter error: %s %g\n";

const	char*	const	FloatException::Message [] =
	{
	"invalid Q",
	"invalid alpha",
	"invalid beta"
	};

////////////////////////////////////////////////////////////////////////////////
//! \par	Description:
//!	Constructor.
//!
//! \param	thisExceptionKind	Kind of the exception.
//! \param	thisValue		Value that caused the exception.
//!
//! \throw	None.
//!
//! \returns	Not applicable
//!
////////////////////////////////////////////////////////////////////////////////

FloatException::FloatException(FloatExceptionType thisExceptionKind,
	float thisValue) noexcept: Exception(),
	ExceptionKind(thisExceptionKind), Value(thisValue)
	{
	}

////////////////////////////////////////////////////////////////////////////////
//! \par	Description:
//!	Write an error message.
//!
//! \param	OutputFile	Pointer to the file on which the message will be
//!				written.
//!
//! \throw	None.
//!
//! \returns	None.
//!
//! \note
//!	If OutputFile is not a valid file, opened for writing, the behavior is
//!	unpredictable.
//!
//! \note
//!	If an error occurs while writing on OutputFile, the process is
//!	terminated.
//!
////////////////////////////////////////////////////////////////////////////////

void	FloatException::Write(FILE* OutputFile) const noexcept
	{
	if (fprintf(OutputFile, ErrorFormat,
		Message [static_cast<unsigned int>(ExceptionKind)], Value) < 0)
		FatalError();
	}

}
