////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	21/09/2021
//!
//! \par	Function:
//!	Contains the definitions of non inline functions of the
//!	GraphicSpace::IntegerException class.
//!
////////////////////////////////////////////////////////////////////////////////

# include	"Graphic.h"
# include	"IntegerException.h"

# include	<string.h>

namespace	GraphicSpace
{

const	char*	const	IntegerException::ErrorFormat =
	"Input data error: %s %" PRIuFAST32 "\n";

const	char*	const	IntegerException::Message [] =
	{
	"invalid file size",
	"invalid bitmap offset",
	"invalid DIB header size",
	"invalid image width",
	"invalid image height",
	"bitmap too large",
	"invalid number of color planes",
	"invalid number of bits per pixel",
	"invalid value for compression",
	"invalid image size",
	"invalid number of colors",
	"invalid number of important colors",
	"invalid number of threads",
	"invalid number of termites",
	"invalid number of steps"
	};

////////////////////////////////////////////////////////////////////////////////
//! \par	Description:
//!	Constructor.
//!
//! \param	thisExceptionKind	Kind of the exception.
//! \param	thisValue		Value that caused the exception.
//!
//! \throw	None.
//!
//! \returns	Not applicable
//!
////////////////////////////////////////////////////////////////////////////////

IntegerException::IntegerException(IntegerExceptionType thisExceptionKind,
	uint_fast32_t thisValue) noexcept: Exception(),
	ExceptionKind(thisExceptionKind), Value(thisValue)
	{
	}

////////////////////////////////////////////////////////////////////////////////
//! \par	Description:
//!	Write an error message.
//!
//! \param	OutputFile	Pointer to the file on which the message will be
//!				written.
//!
//! \throw	None.
//!
//! \returns	None.
//!
//! \note
//!	If OutputFile is not a valid file, opened for writing, the behavior is
//!	unpredictable.
//!
//! \note
//!	If an error occurs while writing on OutputFile, the process is
//!	terminated.
//!
////////////////////////////////////////////////////////////////////////////////

void	IntegerException::Write(FILE* OutputFile) const noexcept
	{
	if (fprintf(OutputFile, ErrorFormat,
		Message [static_cast<unsigned int>(ExceptionKind)], Value) < 0)
		FatalError();
	}

}
