////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	19/11/2021
//!
//! \par	Function:
//!	Contains the definitions of non inline functions of the
//!	GraphicSpace::Interpolator class.
//!
////////////////////////////////////////////////////////////////////////////////

# include	"Graphic.h"
# include	"Interpolator.h"

namespace	GraphicSpace
{

////////////////////////////////////////////////////////////////////////////////
//! \par	Description:
//!	Constructor.
//!
//! \param	thisSize	Number of elements in a side of the square.
//!
//! \throw	None.
//!
//! \returns	Not applicable
//!
////////////////////////////////////////////////////////////////////////////////

Interpolator::Interpolator(register unsigned int thisSize) noexcept(false):
	Size(thisSize), SquaredSize(thisSize * thisSize), InterpolationTable()
	{
	register	unsigned int	Row;
	register	unsigned int	Column;

	for (Row = 0; Row < Size; ++Row)
		for (Column = 0; Column < Size; ++Column)
			{
			InterpolationTable [Row] [Column].UpperLeft =
				(Size - Row) * (Size - Column);
			InterpolationTable [Row] [Column].UpperRight =
				Row * (Size - Column);
			InterpolationTable [Row] [Column].LowerLeft =
				(Size - Row) * Column;
			InterpolationTable [Row] [Column].LowerRight =
				Row * Column;
			}
	}

}
