////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	05/10/2021
//!
//! \par	Function:
//!	Contains the definitions of non inline functions of the
//!	GraphicSpace::NameException class.
//!
////////////////////////////////////////////////////////////////////////////////

# include	"Graphic.h"
# include	"NameException.h"

# include	<string.h>

namespace	GraphicSpace
{

const	char*	const	NameException::ErrorFormat =
	"Input data error: %s %.*s\n";

const	char*	const	NameException::Message [] =
	{
	"invalid file type name"
	};

////////////////////////////////////////////////////////////////////////////////
//! \par	Description:
//!	Constructor.
//!
//! \param	Name	Type name that caused the exception.
//!
//! \throw	None.
//!
//! \returns	Not applicable
//!
//! \see	Bitmap::HEADER_NAME_LENGTH
//!
////////////////////////////////////////////////////////////////////////////////

NameException::NameException(const uint8_t Name [Bitmap::HEADER_NAME_LENGTH])
	noexcept: ExceptionKind(NameExceptionType::INVALID_TYPE_NAME)
	{
	IgnoreValue(memcpy(String, Name, Bitmap::HEADER_NAME_LENGTH));
	}

////////////////////////////////////////////////////////////////////////////////
//! \par	Description:
//!	Write an error message.
//!
//! \param	OutputFile	Pointer to the file on which the message will be
//!				written.
//!
//! \throw	None.
//!
//! \returns	None.
//!
//! \note
//!	If OutputFile is not a valid file, opened for writing, the behavior is
//!	unpredictable.
//!
//! \note
//!	If an error occurs while writing on OutputFile, the process is
//!	terminated.
//!
//! \see	Bitmap::HEADER_NAME_LENGTH
//!
////////////////////////////////////////////////////////////////////////////////

void	NameException::Write(FILE* OutputFile) const noexcept
	{
	if (fprintf(OutputFile, ErrorFormat,
		Message [static_cast<unsigned int>(ExceptionKind)],
		static_cast<int>(Bitmap::HEADER_NAME_LENGTH), String) < 0)
		FatalError();
	}

}
