////////////////////////////////////////////////////////////////////////////////
//! \file
//!
//! \author	Mauro Fiorentini
//!
//! \date	15/08/2022
//!
//! \par	Function:
//!	Contains the definitions of non inline functions of the
//!	GraphicSpace::SystemException class.
//!
////////////////////////////////////////////////////////////////////////////////

# include	"Graphic.h"
# include	"SystemException.h"

namespace	GraphicSpace
{

const	char*	const	SystemException::ErrorFormat = "System error: %s\n";

const	char*	const	SystemException::Message [] =
	{
	"thread initialization error",
	"thread start failure",
	"invalid thread operation",
	"thread join failure",
	"mutex initialization failure",
	"invalid mutex operation",
	"mutex destroy failure",
	"mutex lock failure",
	"mutex unlock failure",
	};

////////////////////////////////////////////////////////////////////////////////
//! \par	Description:
//!	Constructor.
//!
//! \param	thisExceptionKind	Kind of the exception.
//!
//! \throw	None.
//!
//! \returns	Not applicable
//!
////////////////////////////////////////////////////////////////////////////////

SystemException::SystemException(SystemExceptionType thisExceptionKind)
	noexcept: Exception(), ExceptionKind(thisExceptionKind)
	{
	}

////////////////////////////////////////////////////////////////////////////////
//! \par	Description:
//!	Write an error message.
//!
//! \param	OutputFile	Pointer to the file on which the message will be
//!				written.
//!
//! \throw	None.
//!
//! \returns	None.
//!
//! \note
//!	If OutputFile is not a valid file, opened for writing, the behavior is
//!	unpredictable.
//!
//! \note
//!	If an error occurs while writing on OutputFile, the process is
//!	terminated.
//!
////////////////////////////////////////////////////////////////////////////////

void	SystemException::Write(FILE* OutputFile) const noexcept
	{
	if (fprintf(OutputFile, ErrorFormat,
		Message [static_cast<unsigned int>(ExceptionKind)]) < 0)
		FatalError();
	}

}
